# LLAMATOR

## Description 📖

Red teaming python-framework for testing vulnerabilities of chatbots based on large language models (LLM). Supports testing of Russian-language RAG systems.

## Install 🚀

```bash
pip install llamator==1.0.1
```

## Documentation 📚

Documentation Link: [https://romiconez.github.io/llamator](https://romiconez.github.io/llamator/)

## Examples 💡

* 📄 [RAG Chatbot testing via API (RU)](https://github.com/RomiconEZ/llamator/blob/release/examples/llamator-api.ipynb)
* 🧙‍♂️ [Gandalf bot testing via Selenium (RU)](https://github.com/RomiconEZ/llamator/blob/release/examples/llamator-selenium.ipynb)
* 💬 [Telegram bot testing via Telethon (RU)](https://github.com/RomiconEZ/llamator/blob/release/examples/llamator-telegram.ipynb)
* 🔗 [LangChain client testing with custom attack (RU)](https://github.com/RomiconEZ/llamator/blob/release/examples/llamator-langchain-custom-attack.ipynb)

## Supported Clients 🛠️

* 🌐 All LangChain clients
* 🧠 OpenAI-like API
* ⚙️ Custom Class (Telegram, Selenium, etc.)

## Unique Features 🌟

* 🛡️ Support for custom attacks from the user
* 📊 Results of launching each attack in CSV format
* 📈 Report with attack requests and responses for all tests in Excel format
* 📄 Test report document available in DOCX format

## License 📜

This project is licensed under the terms of the **Creative Commons Attribution-NonCommercial-ShareAlike 4.0 International** license. See the LICENSE file for details.

[![Creative Commons License](https://i.creativecommons.org/l/by-nc-sa/4.0/88x31.png)](http://creativecommons.org/licenses/by-nc-sa/4.0/)